Package: alakazam
Type: Package
Version: 0.3.0
Date: 2019-07-17
Authors@R: c(person("Jason", "Vander Heiden", role=c("aut", "cre"), 
                    email="jason.vanderheiden@yale.edu"),
             person("Namita", "Gupta", role=c("aut"), 
                    email="namita.gupta@yale.edu"),
             person("Susanna", "Marquez", role=c("ctb"), 
                    email="susanna.marquez@yale.edu"),
             person("Daniel", "Gadala-Maria", role=c("ctb"), 
                    email="daniel.gadala-maria@yale.edu"),
             person("Ruoyi", "Jiang", role=c("ctb"), 
                    email="ruoyi.jiang@yale.edu"),
             person("Nima", "Nouri", role=c("ctb"), 
                    email="nima.nouri@yale.edu"),
             person("Kenneth", "Hoehn", role=c("ctb"), 
                    email="kenneth.hoehn@yale.edu"),
             person("Julian", "Zhou", role=c("ctb"), 
                    email="julian.zhou@bulldogs.yale.edu"),     
             person("Steven", "Kleinstein", role=c("aut", "cph"), 
                    email="steven.kleinstein@yale.edu"))
Title: Immunoglobulin Clonal Lineage and Diversity Analysis
Description: Provides methods for high-throughput adaptive immune 
    receptor repertoire sequencing (AIRR-Seq; Rep-Seq) analysis. In 
    particular, immunoglobulin (Ig) sequence lineage reconstruction, 
    lineage topology analysis, diversity profiling, amino acid property 
    analysis and gene usage.
    Citations: 
    Gupta and Vander Heiden, et al (2017) <doi:10.1093/bioinformatics/btv359>,
    Stern, Yaari and Vander Heiden, et al (2014) <doi:10.1126/scitranslmed.3008879>.
License: CC BY-SA 4.0
URL: http://alakazam.readthedocs.org
BugReports: https://bitbucket.org/kleinstein/alakazam/issues
LazyData: true
BuildVignettes: true
VignetteBuilder: knitr
Encoding: UTF-8
SystemRequirements: C++11
Depends: R (>= 3.1.2), ggplot2 (>= 2.0.0)
Imports: ape, dplyr (>= 0.8.1), graphics, grid, igraph (>= 1.0.0),
        lazyeval, Matrix, methods, progress, Rcpp (>= 0.12.12), readr,
        rlang, scales, seqinr, stats, stringi, tibble, tidyr, utils
LinkingTo: Rcpp
Suggests: knitr, rmarkdown, testthat
RoxygenNote: 6.1.1
Collate: 'Alakazam.R' 'AminoAcids.R' 'Classes.R' 'Core.R' 'Data.R'
        'Diversity.R' 'Deprecated.R' 'Gene.R' 'Lineage.R'
        'RcppExports.R' 'Sequence.R' 'Topology.R'
NeedsCompilation: yes
Packaged: 2019-07-17 19:15:47 UTC; vandej27
Author: Jason Vander Heiden [aut, cre],
  Namita Gupta [aut],
  Susanna Marquez [ctb],
  Daniel Gadala-Maria [ctb],
  Ruoyi Jiang [ctb],
  Nima Nouri [ctb],
  Kenneth Hoehn [ctb],
  Julian Zhou [ctb],
  Steven Kleinstein [aut, cph]
Maintainer: Jason Vander Heiden <jason.vanderheiden@yale.edu>
Repository: CRAN
Date/Publication: 2019-07-18 11:20:13 UTC
Built: R 3.6.3; x86_64-w64-mingw32; 2020-05-08 05:10:21 UTC; windows
Archs: x64
