# Generated by roxygen2: do not edit by hand

export(ABBREV_AA)
export(DNA_COLORS)
export(IG_COLORS)
export(IMGT_REGIONS)
export(IUPAC_AA)
export(IUPAC_DNA)
export(TR_COLORS)
export(aliphatic)
export(alphaDiversity)
export(aminoAcidProperties)
export(baseTheme)
export(buildPhylipLineage)
export(bulk)
export(calcCoverage)
export(calcDiversity)
export(charge)
export(checkColumns)
export(collapseDuplicates)
export(combineIgphyml)
export(countClones)
export(countGenes)
export(countPatterns)
export(cpuCount)
export(estimateAbundance)
export(extractVRegion)
export(getAAMatrix)
export(getAllele)
export(getDNAMatrix)
export(getFamily)
export(getGene)
export(getMRCA)
export(getPathLengths)
export(getSegment)
export(graphToPhylo)
export(gravy)
export(gridPlot)
export(groupGenes)
export(isValidAASeq)
export(makeChangeoClone)
export(makeTempDir)
export(maskSeqEnds)
export(maskSeqGaps)
export(nonsquareDist)
export(padSeqEnds)
export(pairwiseDist)
export(pairwiseEqual)
export(permuteLabels)
export(phyloToGraph)
export(plotAbundanceCurve)
export(plotDiversityCurve)
export(plotDiversityTest)
export(plotEdgeTest)
export(plotMRCATest)
export(plotSubtrees)
export(polar)
export(progressBar)
export(rarefyDiversity)
export(readChangeoDb)
export(readIgphyml)
export(seqDist)
export(seqEqual)
export(sortGenes)
export(stoufferMeta)
export(summarizeSubtrees)
export(tableEdges)
export(testDiversity)
export(testEdges)
export(testMRCA)
export(translateDNA)
export(translateStrings)
export(writeChangeoDb)
exportClasses(AbundanceCurve)
exportClasses(ChangeoClone)
exportClasses(DiversityCurve)
exportClasses(EdgeTest)
exportClasses(MRCATest)
exportMethods(plot)
exportMethods(print)
import(ggplot2)
import(graphics)
import(methods)
import(utils)
importFrom(Matrix,rowSums)
importFrom(Matrix,sparseMatrix)
importFrom(Rcpp,evalCpp)
importFrom(ape,di2multi)
importFrom(ape,ladderize)
importFrom(ape,read.tree)
importFrom(ape,reorder.phylo)
importFrom(ape,root)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,combine)
importFrom(dplyr,desc)
importFrom(dplyr,do)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_at)
importFrom(dplyr,n)
importFrom(dplyr,one_of)
importFrom(dplyr,rename)
importFrom(dplyr,right_join)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarize)
importFrom(dplyr,summarize_at)
importFrom(dplyr,transmute)
importFrom(dplyr,ungroup)
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,all_shortest_paths)
importFrom(igraph,as_data_frame)
importFrom(igraph,as_edgelist)
importFrom(igraph,components)
importFrom(igraph,degree)
importFrom(igraph,distances)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,groups)
importFrom(igraph,make_directed_graph)
importFrom(igraph,make_graph)
importFrom(igraph,make_undirected_graph)
importFrom(igraph,set_vertex_attr)
importFrom(igraph,shortest_paths)
importFrom(igraph,vertex_attr)
importFrom(lazyeval,interp)
importFrom(progress,progress_bar)
importFrom(readr,cols)
importFrom(readr,read_delim)
importFrom(readr,read_tsv)
importFrom(readr,write_delim)
importFrom(readr,write_tsv)
importFrom(scales,log10_trans)
importFrom(scales,log2_trans)
importFrom(scales,math_format)
importFrom(scales,percent)
importFrom(scales,pretty_breaks)
importFrom(scales,scientific)
importFrom(scales,trans_breaks)
importFrom(scales,trans_format)
importFrom(seqinr,translate)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,dbinom)
importFrom(stats,dmultinom)
importFrom(stats,dnorm)
importFrom(stats,ecdf)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,pbinom)
importFrom(stats,pnorm)
importFrom(stats,qbinom)
importFrom(stats,qnorm)
importFrom(stats,rbinom)
importFrom(stats,rmultinom)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stringi,stri_count_boundaries)
importFrom(stringi,stri_count_fixed)
importFrom(stringi,stri_count_regex)
importFrom(stringi,stri_detect_fixed)
importFrom(stringi,stri_dup)
importFrom(stringi,stri_extract_all_regex)
importFrom(stringi,stri_extract_first_regex)
importFrom(stringi,stri_flatten)
importFrom(stringi,stri_join)
importFrom(stringi,stri_length)
importFrom(stringi,stri_pad_left)
importFrom(stringi,stri_pad_right)
importFrom(stringi,stri_paste)
importFrom(stringi,stri_replace_all_regex)
importFrom(stringi,stri_replace_first_regex)
importFrom(stringi,stri_split_fixed)
importFrom(tibble,tibble)
importFrom(tidyr,complete)
importFrom(tidyr,gather)
useDynLib(alakazam, .registration=TRUE)
